# Mapel-marriages
This pacakge is a plugin for [mapel](https://pypi.org/project/mapel/) extending
it with necessary files to draw maps of Stable Roommates intances.

For the most recent version of mapel, visit its [git
repo](https://pypi.org/project/mapel/).

# Installation
For a simple installation, type:
`pip install mapel-roommates`
in the console.

For more complicated variants of installation, refer to the readme of mapel
[here](https://github.com/szufix/mapel).

# Acknowledgments

This project is part of the [PRAGMA project](https://home.agh.edu.pl/~pragma/)
which has received funding from the [European Research Council
(ERC)](https://home.agh.edu.pl/~pragma/) under the European Union’s Horizon 2020
research and innovation programme ([grant agreement No
101002854](https://erc.easme-web.eu/?p=101002854)).



